"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseUpdateArgs = exports.mergeFieldPathData = void 0;

var _FieldPath = _interopRequireDefault(require("../FieldPath"));

var _utils = require("../../../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const buildFieldPathData = (segments, value) => {
  if (segments.length === 1) {
    return {
      [segments[0]]: value
    };
  }

  return {
    [segments[0]]: buildFieldPathData(segments.slice(1), value)
  };
}; // eslint-disable-next-line import/prefer-default-export


const mergeFieldPathData = (data, segments, value) => {
  if (segments.length === 1) {
    return _objectSpread({}, data, {
      [segments[0]]: value
    });
  }

  if (data[segments[0]]) {
    return _objectSpread({}, data, {
      [segments[0]]: mergeFieldPathData(data[segments[0]], segments.slice(1), value)
    });
  }

  return _objectSpread({}, data, {
    [segments[0]]: buildFieldPathData(segments.slice(1), value)
  });
};

exports.mergeFieldPathData = mergeFieldPathData;

const parseUpdateArgs = (args, methodName) => {
  let data = {};

  if (args.length === 1) {
    if (!(0, _utils.isObject)(args[0])) {
      throw new Error(`${methodName} failed: If using a single update argument, it must be an object.`);
    }

    var _args = _slicedToArray(args, 1);

    data = _args[0];
  } else if (args.length % 2 === 1) {
    throw new Error(`${methodName} failed: The update arguments must be either a single object argument, or equal numbers of key/value pairs.`);
  } else {
    for (let i = 0; i < args.length; i += 2) {
      const key = args[i];
      const value = args[i + 1];

      if ((0, _utils.isString)(key)) {
        data[key] = value;
      } else if (key instanceof _FieldPath.default) {
        data = mergeFieldPathData(data, key._segments, value);
      } else {
        throw new Error(`${methodName} failed: Argument at index ${i} must be a string or FieldPath`);
      }
    }
  }

  return data;
};

exports.parseUpdateArgs = parseUpdateArgs;